@@ -30,6 +30,8 @@ namespace morphodita {
 
 class english_morpho : public morpho {
  public:
+  english_morpho(unsigned version) : version(version) {}
+
   virtual int analyze(string_piece form, morpho::guesser_mode guesser, vector<tagged_lemma>& lemmas) const override;
   virtual int generate(string_piece lemma, const char* tag_wildcard, guesser_mode guesser, vector<tagged_lemma_forms>& forms) const;
   virtual int raw_lemma_len(string_piece lemma) const override;
@@ -41,6 +43,7 @@ class english_morpho : public morpho {
  private:
   inline void analyze_special(string_piece form, vector<tagged_lemma>& lemmas) const;
 
+  unsigned version;
   morpho_dictionary<english_lemma_addinfo> dictionary;
   english_morpho_guesser morpho_guesser;
 
@@ -49,7 +52,7 @@ class english_morpho : public morpho {
   string open_quotation_tag = "``", close_quotation_tag = "''";
   string open_parenthesis_tag = "(", close_parenthesis_tag = ")";
   string comma_tag = ",", dot_tag = ".", punctuation_tag = ":", hash_tag = "#", dollar_tag = "$";
-  string sym_tag = "SYM", jj_tag = "JJ", nn_tag = "NN", cc_tag = "CC", pos_tag = "POS", in_tag = "IN";
+  string sym_tag = "SYM", jj_tag = "JJ", nn_tag = "NN", nns_tag = "NNS", cc_tag = "CC", pos_tag = "POS", in_tag = "IN";
 };
 
 } // namespace morphodita
